@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'aws-partitions/endpoint_provider'
 require_relative 'aws-partitions/partition'
 require_relative 'aws-partitions/partition_list'
@@ -224,10 +226,12 @@ module Aws
             'ACM' => 'acm',
             'ACMPCA' => 'acm-pca',
             'APIGateway' => 'apigateway',
+            'AccessAnalyzer' => 'access-analyzer',
             'AlexaForBusiness' => 'a4b',
             'Amplify' => 'amplify',
             'ApiGatewayManagementApi' => 'execute-api',
             'ApiGatewayV2' => 'apigateway',
+            'AppConfig' => 'appconfig',
             'AppMesh' => 'appmesh',
             'AppStream' => 'appstream2',
             'AppSync' => 'appsync',
@@ -235,8 +239,9 @@ module Aws
             'ApplicationDiscoveryService' => 'discovery',
             'ApplicationInsights' => 'applicationinsights',
             'Athena' => 'athena',
+            'AugmentedAIRuntime' => 'a2i-runtime.sagemaker',
             'AutoScaling' => 'autoscaling',
-            'AutoScalingPlans' => 'autoscaling',
+            'AutoScalingPlans' => 'autoscaling-plans',
             'Backup' => 'backup',
             'Batch' => 'batch',
             'Budgets' => 'budgets',
@@ -252,31 +257,41 @@ module Aws
             'CloudWatch' => 'monitoring',
             'CloudWatchEvents' => 'events',
             'CloudWatchLogs' => 'logs',
+            'CodeArtifact' => 'codeartifact',
             'CodeBuild' => 'codebuild',
             'CodeCommit' => 'codecommit',
             'CodeDeploy' => 'codedeploy',
+            'CodeGuruProfiler' => 'codeguru-profiler',
+            'CodeGuruReviewer' => 'codeguru-reviewer',
             'CodePipeline' => 'codepipeline',
             'CodeStar' => 'codestar',
+            'CodeStarNotifications' => 'codestar-notifications',
+            'CodeStarconnections' => 'codestar-connections',
             'CognitoIdentity' => 'cognito-identity',
             'CognitoIdentityProvider' => 'cognito-idp',
             'CognitoSync' => 'cognito-sync',
             'Comprehend' => 'comprehend',
             'ComprehendMedical' => 'comprehendmedical',
+            'ComputeOptimizer' => 'compute-optimizer',
             'ConfigService' => 'config',
             'Connect' => 'connect',
+            'ConnectParticipant' => 'participant.connect',
             'CostExplorer' => 'ce',
             'CostandUsageReportService' => 'cur',
             'DAX' => 'dax',
             'DLM' => 'dlm',
+            'DataExchange' => 'dataexchange',
             'DataPipeline' => 'datapipeline',
             'DataSync' => 'datasync',
             'DatabaseMigrationService' => 'dms',
+            'Detective' => 'api.detective',
             'DeviceFarm' => 'devicefarm',
             'DirectConnect' => 'directconnect',
             'DirectoryService' => 'ds',
             'DocDB' => 'rds',
             'DynamoDB' => 'dynamodb',
             'DynamoDBStreams' => 'streams.dynamodb',
+            'EBS' => 'ebs',
             'EC2' => 'ec2',
             'EC2InstanceConnect' => 'ec2-instance-connect',
             'ECR' => 'api.ecr',
@@ -286,6 +301,7 @@ module Aws
             'EMR' => 'elasticmapreduce',
             'ElastiCache' => 'elasticache',
             'ElasticBeanstalk' => 'elasticbeanstalk',
+            'ElasticInference' => 'api.elastic-inference',
             'ElasticLoadBalancing' => 'elasticloadbalancing',
             'ElasticLoadBalancingV2' => 'elasticloadbalancing',
             'ElasticTranscoder' => 'elastictranscoder',
@@ -296,6 +312,7 @@ module Aws
             'Firehose' => 'firehose',
             'ForecastQueryService' => 'forecastquery',
             'ForecastService' => 'forecast',
+            'FraudDetector' => 'frauddetector',
             'GameLift' => 'gamelift',
             'Glacier' => 'glacier',
             'GlobalAccelerator' => 'globalaccelerator',
@@ -304,7 +321,10 @@ module Aws
             'GroundStation' => 'groundstation',
             'GuardDuty' => 'guardduty',
             'Health' => 'health',
+            'Honeycode' => 'honeycode',
             'IAM' => 'iam',
+            'IVS' => 'ivs',
+            'Imagebuilder' => 'imagebuilder',
             'ImportExport' => 'importexport',
             'Inspector' => 'inspector',
             'IoT' => 'iot',
@@ -314,15 +334,19 @@ module Aws
             'IoTEvents' => 'iotevents',
             'IoTEventsData' => 'data.iotevents',
             'IoTJobsDataPlane' => 'data.jobs.iot',
+            'IoTSecureTunneling' => 'api.tunneling.iot',
+            'IoTSiteWise' => 'iotsitewise',
             'IoTThingsGraph' => 'iotthingsgraph',
             'KMS' => 'kms',
             'Kafka' => 'kafka',
+            'Kendra' => 'kendra',
             'Kinesis' => 'kinesis',
             'KinesisAnalytics' => 'kinesisanalytics',
             'KinesisAnalyticsV2' => 'kinesisanalytics',
             'KinesisVideo' => 'kinesisvideo',
             'KinesisVideoArchivedMedia' => 'kinesisvideo',
             'KinesisVideoMedia' => 'kinesisvideo',
+            'KinesisVideoSignalingChannels' => 'kinesisvideo',
             'LakeFormation' => 'lakeformation',
             'Lambda' => 'lambda',
             'LambdaPreview' => 'lambda',
@@ -334,7 +358,9 @@ module Aws
             'MTurk' => 'mturk-requester',
             'MachineLearning' => 'machinelearning',
             'Macie' => 'macie',
+            'Macie2' => 'macie2',
             'ManagedBlockchain' => 'managedblockchain',
+            'MarketplaceCatalog' => 'catalog.marketplace',
             'MarketplaceCommerceAnalytics' => 'marketplacecommerceanalytics',
             'MarketplaceEntitlementService' => 'entitlement.marketplace',
             'MarketplaceMetering' => 'metering.marketplace',
@@ -347,11 +373,14 @@ module Aws
             'MediaStoreData' => 'data.mediastore',
             'MediaTailor' => 'api.mediatailor',
             'MigrationHub' => 'mgh',
+            'MigrationHubConfig' => 'migrationhub-config',
             'Mobile' => 'mobile',
             'Neptune' => 'rds',
+            'NetworkManager' => 'networkmanager',
             'OpsWorks' => 'opsworks',
             'OpsWorksCM' => 'opsworks-cm',
             'Organizations' => 'organizations',
+            'Outposts' => 'outposts',
             'PI' => 'pi',
             'Personalize' => 'personalize',
             'PersonalizeEvents' => 'personalize-events',
@@ -378,14 +407,19 @@ module Aws
             'S3' => 's3',
             'S3Control' => 's3-control',
             'SES' => 'email',
+            'SESV2' => 'email',
             'SMS' => 'sms',
             'SNS' => 'sns',
             'SQS' => 'sqs',
             'SSM' => 'ssm',
+            'SSO' => 'portal.sso',
+            'SSOOIDC' => 'oidc',
             'STS' => 'sts',
             'SWF' => 'swf',
             'SageMaker' => 'api.sagemaker',
             'SageMakerRuntime' => 'runtime.sagemaker',
+            'SavingsPlans' => 'savingsplans',
+            'Schemas' => 'schemas',
             'SecretsManager' => 'secretsmanager',
             'SecurityHub' => 'securityhub',
             'ServerlessApplicationRepository' => 'serverlessrepo',
@@ -399,6 +433,7 @@ module Aws
             'States' => 'states',
             'StorageGateway' => 'storagegateway',
             'Support' => 'support',
+            'Synthetics' => 'synthetics',
             'Textract' => 'textract',
             'TranscribeService' => 'transcribe',
             'TranscribeStreamingService' => 'transcribestreaming',
@@ -406,9 +441,11 @@ module Aws
             'Translate' => 'translate',
             'WAF' => 'waf',
             'WAFRegional' => 'waf-regional',
+            'WAFV2' => 'wafv2',
             'WorkDocs' => 'workdocs',
             'WorkLink' => 'worklink',
             'WorkMail' => 'workmail',
+            'WorkMailMessageFlow' => 'workmailmessageflow',
             'WorkSpaces' => 'workspaces',
             'XRay' => 'xray',
           }
